@@ -16,9 +16,6 @@ mod name_server_stats;
 
 pub use self::connection_provider::{ConnectionProvider, RuntimeProvider, Spawn};
 pub use self::connection_provider::{GenericConnection, GenericConnector};
-#[cfg(feature = "mdns")]
-#[cfg_attr(docsrs, doc(cfg(feature = "mdns")))]
-pub(crate) use self::name_server::mdns_nameserver;
 pub use self::name_server::{GenericNameServer, NameServer};
 pub use self::name_server_pool::{GenericNameServerPool, NameServerPool};
 use self::name_server_state::NameServerState;
